==> quarchpy-2.1.14.dev5-py2.py3-none-any.whl: quarchpy/connection_specific/connection_ReST.py <==
import socket

try:
    import httplib as httplib
except ImportError:
    import http.client as httplib

class ReSTConn:
    def __init__(self, ConnTarget):
        self.ConnTarget = ConnTarget

        self.Connection = httplib.HTTPConnection(self.ConnTarget, 80, timeout=10)
        self.Connection.close()
        
    def close(self):
        return True

    def sendCommand(self, Command, expectedResponse = True, max_retries=1):
        Command = "/" + Command.replace(" ", "%20")
        for attempt in range(1, max_retries + 1):
            try:
                self.Connection.request("GET", Command)
                if expectedResponse == True:
                    R2 = self.Connection.getresponse()
                    if R2.status == 200:
                        Result = R2.read()
                        Result = Result.decode()
                        Result = Result.strip('> \t\n\r')
                        self.Connection.close()
                        return Result
                    else:
                        print ("FAIL - Please power cycle the module!")
                        self.Connection.close()
                        return "FAIL: ", R1.status, R1.reason
                else:
                    return None
            except socket.timeout as e:
                if attempt < max_retries:
                    print("Socket timed out, retrying command...")
                else:
                    print("Maximum number of retries reached. Exiting.")
                    raise e

==> quarchpy-2.1.15-py2.py3-none-any.whl: quarchpy/connection_specific/connection_ReST.py <==
import socket, logging

try:
    import httplib as httplib
except ImportError:
    import http.client as httplib

class ReSTConn:
    def __init__(self, ConnTarget):
        self.ConnTarget = ConnTarget

        self.Connection = httplib.HTTPConnection(self.ConnTarget, 80, timeout=10)
        self.Connection.close()
        
    def close(self):
        return True

    def sendCommand(self, Command, expectedResponse = True, max_retries=1):
        Command = "/" + Command.replace(" ", "%20")
        for attempt in range(1, max_retries + 1):
            try:
                self.Connection.request("GET", Command)
                if expectedResponse == True:
                    R2 = self.Connection.getresponse()
                    if R2.status == 200:
                        Result = R2.read()
                        Result = Result.decode()
                        Result = Result.strip('> \t\n\r')
                        self.Connection.close()
                        return Result
                    else:
                        logging.error("FAIL - Please power cycle the module!")
                        self.Connection.close()
                        return "FAIL: ", R1.status, R1.reason
                else:
                    return None
            except socket.timeout as e:
                if attempt < max_retries:
                    logging.warning("Socket timed out, retrying command...")
                else:
                    logging.error("Maximum number of retries reached. Exiting.")
                    raise e
